<!DOCTYPE html>
<html lang="fr">

	<head>
		<meta charset="utf-8">
		<title>JavaScript - Boilerplate</title>

		<link href="https://fonts.googleapis.com/css?family=Notable|Oswald"		rel="stylesheet" />
		<link href="https://use.fontawesome.com/releases/v5.3.1/css/all.css"	rel="stylesheet" />

		<link href="css/normalize.css" 																				rel="stylesheet" type="text/css" />
		<!-- Utilisation d'une variable GET unique afin de ne pas souffrir du cache serveur -->
		<link href="css/styles.css?unq=<?= time(); ?>" 												rel="stylesheet" type="text/css" />

		<link href="ressources/images/favicon.ico"														rel="shortcut icon"  >
	</head>

	<body>
		<div class="header"></div>
		<div class="container">
			<div class="left">
				<h1>Boil<span class="orange">erp</span>late</h1>
			</div>
			<div class="right">
				<h2 class="title"><i class="fas fa-cocktail"></i><span> Loterie</span></h2>
				<p>Génération de 6 numéros aléatoires uniques, rangés dans par ordre croissant :)</p>

				<?php
					// Algorithme utilisé :
					//			1. Générer un tableau contenant les 50 premiers numéros
					//			2. Le mélanger (ordre aléatoire)
					//			3. Extraire les 6 premières cases dans un tableau des résultats
					//			4. Ordonner les résultats
					//
					// 			Note : Cette méthode est l'une des plus optimisée, car elle évite l'utilisation de boucles de vérifications <3

					// Variables / Constantes
					$NOMBRE_TIRAGES = 6;
					$RANG_MAX 			= 50;
					$RANG_MIN 			= 0;

					// Générer un tableau contenant les 50 premiers numéros
					$tableau = array();

					// Le tableau est rempli grâce à l'index : [0, 1, 2, 3, 4, 5, .... 50]
					for($i = $RANG_MIN ; $i <= $RANG_MAX ; $i++){
						$tableau[] = $i;
					}
					// Vérification du contenu du tableau d'origine
					// var_dump($tableau);

					// Le mélanger // http://php.net/manual/fr/function.shuffle.php
					shuffle($tableau);
					// Vérification que le contenu du tableau d'origine à bien été mélangé
					// var_dump($tableau);

					// Extraire les 6 premières cases dans un autre tableau // http://php.net/manual/fr/function.array-slice.php
					$tirage = array_slice($tableau, 0, $NOMBRE_TIRAGES);
					// Vérification du tirage
					// var_dump($tirage);

					// Ordonner // http://php.net/manual/fr/function.sort.php
					sort($tirage);
					// Vérification de l'ordonnancement
					// var_dump($tirage);

					// Afficher, pour les fainéants // http://php.net/manual/fr/function.implode.php
				?>
				<p>Le résultat du tirage est le suivant : <strong><?= implode(', ', $tirage) ?></strong> !</p>

				<!-- document.write ajoutera le contenu ici -->
				<script src="js/functions.js?unq=<?= time(); ?>"></script>
				<script src="js/main.js?unq=<?= time(); ?>"></script>
			</div>
		</div>
	</body>

</html>
